@@ -4,6 +4,7 @@ import asyncio
 import logging
 from typing import Dict, Optional, List, Any
 from mcpbundles_proxy.services.browser import BrowserService
+from mcpbundles_proxy.services.sqlite import SQLiteService
 
 logger = logging.getLogger(__name__)
 
@@ -14,6 +15,7 @@ class ServiceManager:
     def __init__(self) -> None:
         self.services: Dict[str, Any] = {}
         self.browser: Optional[BrowserService] = None
+        self.sqlite: Optional[SQLiteService] = None
         
     async def discover_services(self, ports: List[int]) -> dict:
         """Scan which ports are listening on localhost.
@@ -41,50 +43,24 @@ class ServiceManager:
                     pass  # Ignore close errors during discovery
                 
                 results[str(port)] = {
-                    "available": True,
-                    "type": self._detect_service_type(port)
+                    "available": True
                 }
                 logger.debug(f"Port {port}: available")
                 
             except (asyncio.TimeoutError, ConnectionRefusedError, OSError):
                 results[str(port)] = {
-                    "available": False,
-                    "type": None
+                    "available": False
                 }
                 logger.debug(f"Port {port}: not available")
             except Exception as e:
                 logger.error(f"Error scanning port {port}: {e}")
                 results[str(port)] = {
-                    "available": False,
-                    "type": None,
-                    "error": str(e)
+                    "available": False
                 }
         
         logger.info(f"Discovery complete: {sum(1 for r in results.values() if r['available'])} services found")
         return results
     
-    def _detect_service_type(self, port: int) -> Optional[str]:
-        """Detect likely service type based on port.
-        
-        Common ports:
-        - 5432, 5433: PostgreSQL
-        - 3306: MySQL
-        - 6379: Redis
-        - 27017: MongoDB
-        - 9200: Elasticsearch
-        - 9223: Browser (Chromium debugging)
-        """
-        port_map = {
-            5432: "postgresql",
-            5433: "postgresql",
-            3306: "mysql",
-            6379: "redis",
-            27017: "mongodb",
-            9200: "elasticsearch",
-            9223: "browser",
-        }
-        return port_map.get(port, "unknown")
-    
     async def verify_service(self, target: str) -> dict:
         """Verify that a service is actually reachable.
         
@@ -123,8 +99,7 @@ class ServiceManager:
             logger.info(f"✅ Service verified: {target}")
             return {
                 "verified": True,
-                "target": target,
-                "service_type": self._detect_service_type(port)  # Changed from 'type' to 'service_type'
+                "target": target
             }
             
         except asyncio.TimeoutError:
@@ -170,6 +145,8 @@ class ServiceManager:
         
         if service == "browser":
             return await self._start_browser(config)
+        elif service == "sqlite":
+            return await self._start_sqlite(config)
         else:
             logger.warning(f"Unknown service type: {service}")
             return {
@@ -187,6 +164,7 @@ class ServiceManager:
                 logger.info("Browser already running")
                 return {
                     "started": True,
+                    "service": "browser",
                     "already_running": True,
                     "port": self.browser.port,
                     "mode": "hidden" if self.browser.headless else "visible"
@@ -207,12 +185,46 @@ class ServiceManager:
             logger.error("Playwright not installed")
             return {
                 "started": False,
+                "service": "browser",
                 "error": "Playwright not installed. Install with: pip install mcpbundles-proxy[browser]"
             }
         except Exception as e:
             logger.error(f"Failed to start browser: {e}")
             return {
                 "started": False,
+                "service": "browser",
+                "error": str(e)
+            }
+    
+    async def _start_sqlite(self, config: dict) -> dict:
+        """Start SQLite service."""
+        try:
+            port = config.get('port', 9999)
+            
+            if self.sqlite and self.sqlite.running:
+                logger.info("SQLite service already running")
+                return {
+                    "started": True,
+                    "service": "sqlite",
+                    "already_running": True,
+                    "port": self.sqlite.port,
+                }
+            
+            self.sqlite = SQLiteService(port=port)
+            await self.sqlite.start()
+            self.services['sqlite'] = self.sqlite
+            
+            return {
+                "started": True,
+                "service": "sqlite",
+                "port": port,
+            }
+            
+        except Exception as e:
+            logger.error(f"Failed to start SQLite service: {e}")
+            return {
+                "started": False,
+                "service": "sqlite",
                 "error": str(e)
             }
     
@@ -229,6 +241,8 @@ class ServiceManager:
         
         if service == "browser":
             return await self._stop_browser()
+        elif service == "sqlite":
+            return await self._stop_sqlite()
         else:
             logger.warning(f"Unknown service type: {service}")
             return {
@@ -262,6 +276,32 @@ class ServiceManager:
                 "error": str(e)
             }
     
+    async def _stop_sqlite(self) -> dict:
+        """Stop SQLite service."""
+        try:
+            if not self.sqlite or not self.sqlite.running:
+                logger.info("SQLite service not running")
+                return {
+                    "stopped": True,
+                    "was_running": False
+                }
+            
+            await self.sqlite.stop()
+            self.sqlite = None
+            self.services.pop('sqlite', None)
+            
+            return {
+                "stopped": True,
+                "service": "sqlite"
+            }
+            
+        except Exception as e:
+            logger.error(f"Error stopping SQLite service: {e}")
+            return {
+                "stopped": False,
+                "error": str(e)
+            }
+    
     async def update_service(self, service: str, config: dict) -> dict:
         """Update service configuration.
         
@@ -345,6 +385,14 @@ class ServiceManager:
                 "mode": "disabled"
             }
         
+        if self.sqlite:
+            status['sqlite'] = self.sqlite.get_status()
+        else:
+            status['sqlite'] = {
+                "enabled": False,
+                "port": 9999,
+            }
+        
         return status
     
     async def stop_all(self):
@@ -355,5 +403,9 @@ class ServiceManager:
             await self.browser.stop()
             self.browser = None
         
+        if self.sqlite:
+            await self.sqlite.stop()
+            self.sqlite = None
+        
         self.services.clear()
 
