@@ -8,11 +8,19 @@ import logging
 import base64
 import ssl
 import certifi
+import os
 from typing import Dict, Any, Optional
 from asyncio import Future
 from websockets.asyncio.client import ClientConnection
 from urllib.parse import quote
 
+# Load environment variables from .env file
+try:
+    from dotenv import load_dotenv  # type: ignore
+    load_dotenv()
+except ImportError:
+    pass  # dotenv not available, will use system env vars
+
 logger = logging.getLogger(__name__)
 
 
@@ -88,10 +96,19 @@ class TunnelClient:
         """Connect and maintain WebSocket tunnel with auto-reconnect."""
         # URL-encode the token to handle special characters
         encoded_token = quote(self.token, safe='')
-        uri = f"wss://api.mcpbundles.com/api/tunnel/connect?token={encoded_token}"
         
-        # Create SSL context with certifi's CA bundle
-        ssl_context = ssl.create_default_context(cafile=certifi.where())
+        # Check if in development mode
+        is_dev = os.getenv('ENVIRONMENT') == 'development'
+        
+        if is_dev:
+            # Development mode: use local websocket server without SSL
+            uri = f"ws://localhost:8000/api/tunnel/connect?token={encoded_token}"
+            ssl_context = None
+            logger.info("🔧 Development mode: connecting to localhost:8000")
+        else:
+            # Production mode: use wss with certifi SSL context
+            uri = f"wss://api.mcpbundles.com/api/tunnel/connect?token={encoded_token}"
+            ssl_context = ssl.create_default_context(cafile=certifi.where())
         
         while self.running:
             try:
@@ -155,6 +172,10 @@ class TunnelClient:
                     # Forward HTTP request to localhost
                     asyncio.create_task(self.handle_request(data))
                 
+                elif msg_type == 'ping':
+                    # Backend keepalive ping - respond with pong
+                    await self.send_response('pong', {})
+                
                 elif msg_type == 'service_discovery':
                     # Discover available local services
                     asyncio.create_task(self.handle_service_discovery(data))
@@ -331,26 +352,51 @@ class TunnelClient:
             config = data.get('config', {})
             logger.info(f"Received service start request for {service}")
             
+            if not service:
+                logger.warning("Service start request missing service name")
+                await self.send_response('service_started', {
+                    'started': False,
+                    'error': 'Missing required field: service',
+                    'error_code': 'MISSING_SERVICE_NAME'
+                })
+                return
+            
             if not self.service_manager:
                 logger.warning("No service manager configured")
                 await self.send_response('service_started', {
                     'started': False,
-                    'error': 'Service manager not available'
+                    'error': 'Service manager not available (proxy misconfiguration)',
+                    'error_code': 'SERVICE_MANAGER_UNAVAILABLE'
                 })
                 return
             
             # Start service
             result = await self.service_manager.start_service(service, config)
             
+            # Add error_code to result if it failed
+            if not result.get('started') and 'error_code' not in result:
+                error_msg = result.get('error', '')
+                if 'Playwright not installed' in error_msg:
+                    result['error_code'] = 'PLAYWRIGHT_NOT_INSTALLED'
+                elif 'Unknown service' in error_msg:
+                    result['error_code'] = 'UNKNOWN_SERVICE'
+                else:
+                    result['error_code'] = 'START_FAILED'
+            
             # Send result back
             await self.send_response('service_started', result)
-            logger.info(f"Service start complete for {service}: {result.get('started')}")
+            
+            if result.get('started'):
+                logger.info(f"✅ Service {service} started successfully")
+            else:
+                logger.error(f"❌ Service {service} failed to start: {result.get('error')}")
             
         except Exception as e:
-            logger.error(f"Error handling service start: {e}")
+            logger.error(f"Error handling service start: {e}", exc_info=True)
             await self.send_response('service_started', {
                 'started': False,
-                'error': str(e)
+                'error': f'Internal error starting service: {e}',
+                'error_code': 'INTERNAL_ERROR'
             })
     
     async def handle_service_stop(self, data: dict):
@@ -494,7 +540,8 @@ class TunnelClient:
             if not target or ':' not in target:
                 await self.send_response('tunnel_error', {
                     'tunnel_id': tunnel_id,
-                    'error': 'Invalid target format. Expected "host:port"'
+                    'error': 'Invalid target format. Expected "host:port"',
+                    'error_code': 'INVALID_TARGET'
                 })
                 return
             
@@ -502,13 +549,29 @@ class TunnelClient:
             if not target.startswith(('localhost:', '127.0.0.1:')):
                 await self.send_response('tunnel_error', {
                     'tunnel_id': tunnel_id,
-                    'error': 'Only localhost targets allowed'
+                    'error': 'Only localhost targets allowed',
+                    'error_code': 'INVALID_HOST'
                 })
                 return
             
             host, port_str = target.split(':', 1)
             port = int(port_str)
             
+            # Special handling for browser service (port 9223)
+            if port == 9223:
+                # Check if browser service is running
+                if self.service_manager:
+                    browser = self.service_manager.services.get('browser')
+                    if not browser or not browser.running:
+                        await self.send_response('tunnel_error', {
+                            'tunnel_id': tunnel_id,
+                            'error': 'Browser service not running. Send service_start message first with: {"type":"service_start","service":"browser","config":{"headless":false,"port":9223}}',
+                            'error_code': 'SERVICE_NOT_RUNNING',
+                            'service': 'browser',
+                            'required_action': 'service_start'
+                        })
+                        return
+            
             # Open TCP connection
             reader, writer = await asyncio.wait_for(
                 asyncio.open_connection(host, port),
@@ -530,28 +593,48 @@ class TunnelClient:
             logger.info(f"✅ Tunnel {tunnel_id} opened to {target}")
             
         except asyncio.TimeoutError:
-            logger.error(f"Tunnel {tunnel_id} connection timeout")
+            error_msg = f'Connection timeout to {target}. Service may not be running.'
+            logger.error(f"Tunnel {tunnel_id}: {error_msg}")
             await self.send_response('tunnel_error', {
                 'tunnel_id': tunnel_id,
-                'error': 'Connection timeout'
+                'error': error_msg,
+                'error_code': 'CONNECTION_TIMEOUT',
+                'target': target
             })
         except ConnectionRefusedError:
-            logger.error(f"Tunnel {tunnel_id} connection refused")
+            # Provide helpful error based on port
+            if port == 9223:
+                error_msg = f'Browser service not running on {target}. Start it first with service_start message.'
+                suggestion = 'Send: {"type":"service_start","service":"browser","config":{"headless":false,"port":9223}}'
+            else:
+                error_msg = f'Connection refused to {target}. Service not running or not listening on this port.'
+                suggestion = f'Verify service is running: lsof -i :{port}'
+            
+            logger.error(f"Tunnel {tunnel_id}: {error_msg}")
             await self.send_response('tunnel_error', {
                 'tunnel_id': tunnel_id,
-                'error': 'Connection refused'
+                'error': error_msg,
+                'error_code': 'CONNECTION_REFUSED',
+                'target': target,
+                'suggestion': suggestion
             })
         except ValueError as e:
-            logger.error(f"Tunnel {tunnel_id} invalid port: {e}")
+            error_msg = f'Invalid port in {target}: {e}'
+            logger.error(f"Tunnel {tunnel_id}: {error_msg}")
             await self.send_response('tunnel_error', {
                 'tunnel_id': tunnel_id,
-                'error': f'Invalid port: {e}'
+                'error': error_msg,
+                'error_code': 'INVALID_PORT',
+                'target': target
             })
         except Exception as e:
-            logger.error(f"Tunnel {tunnel_id} open failed: {e}")
+            error_msg = f'Failed to open tunnel to {target}: {e}'
+            logger.error(f"Tunnel {tunnel_id}: {error_msg}")
             await self.send_response('tunnel_error', {
                 'tunnel_id': tunnel_id,
-                'error': str(e)
+                'error': error_msg,
+                'error_code': 'TUNNEL_OPEN_FAILED',
+                'target': target
             })
     
     async def handle_tunnel_data(self, data: dict):
