@@ -24,7 +24,6 @@ async def test_discover_services_success():
         assert '5432' in result
         assert '6379' in result
         assert result['5432']['available'] is True
-        assert result['5432']['type'] == 'postgresql'
 
 
 @pytest.mark.asyncio
@@ -67,7 +66,6 @@ async def test_verify_service_success():
         
         assert result['verified'] is True
         assert result['target'] == 'localhost:5432'
-        assert result['service_type'] == 'postgresql'
 
 
 @pytest.mark.asyncio
@@ -197,17 +195,6 @@ async def test_update_browser_not_running():
         assert result['started'] is True
 
 
-def test_detect_service_type():
-    """Test service type detection."""
-    manager = ServiceManager()
-    
-    assert manager._detect_service_type(5432) == 'postgresql'
-    assert manager._detect_service_type(5433) == 'postgresql'
-    assert manager._detect_service_type(3306) == 'mysql'
-    assert manager._detect_service_type(6379) == 'redis'
-    assert manager._detect_service_type(27017) == 'mongodb'
-    assert manager._detect_service_type(9223) == 'browser'
-    assert manager._detect_service_type(9999) == 'unknown'
 
 
 @pytest.mark.asyncio
